summaryrefslogtreecommitdiffstats
path: root/nixos/modules/testing
diff options
context:
space:
mode:
authorTuomas Tynkkynen <tuomas.tynkkynen@iki.fi>2017-11-24 14:31:50 +0200
committerTuomas Tynkkynen <tuomas.tynkkynen@iki.fi>2017-11-26 11:13:21 +0200
commite56da6a4642c843d7ba88f513840da7d473eecec (patch)
treec1ab418ccbdac349c8e18da91d6731029d53d03d /nixos/modules/testing
parent0a2eda7a7e3cf7eadb0401f07071e1a3c22a4675 (diff)
nixos/qemu-vm: Use different serial port on ARM/AArch64
Diffstat (limited to 'nixos/modules/testing')
-rw-r--r--nixos/modules/testing/test-instrumentation.nix22
1 files changed, 14 insertions, 8 deletions
diff --git a/nixos/modules/testing/test-instrumentation.nix b/nixos/modules/testing/test-instrumentation.nix
index 7f5b55d5cca0..1d6c41406107 100644
--- a/nixos/modules/testing/test-instrumentation.nix
+++ b/nixos/modules/testing/test-instrumentation.nix
@@ -5,7 +5,13 @@
with lib;
-let kernel = config.boot.kernelPackages.kernel; in
+let
+ kernel = config.boot.kernelPackages.kernel;
+ # FIXME: figure out a common place for this instead of copy pasting
+ serialDevice = if pkgs.stdenv.isi686 || pkgs.stdenv.isx86_64 then "ttyS0"
+ else if pkgs.stdenv.isArm || pkgs.stdenv.isAarch64 then "ttyAMA0"
+ else throw "Unknown QEMU serial device for system '${pkgs.stdenv.system}'";
+in
{
@@ -22,8 +28,8 @@ let kernel = config.boot.kernelPackages.kernel; in
systemd.services.backdoor =
{ wantedBy = [ "multi-user.target" ];
- requires = [ "dev-hvc0.device" "dev-ttyS0.device" ];
- after = [ "dev-hvc0.device" "dev-ttyS0.device" ];
+ requires = [ "dev-hvc0.device" "dev-${serialDevice}.device" ];
+ after = [ "dev-hvc0.device" "dev-${serialDevice}.device" ];
script =
''
export USER=root
@@ -40,7 +46,7 @@ let kernel = config.boot.kernelPackages.kernel; in
cd /tmp
exec < /dev/hvc0 > /dev/hvc0
- while ! exec 2> /dev/ttyS0; do sleep 0.1; done
+ while ! exec 2> /dev/${serialDevice}; do sleep 0.1; done
echo "connecting to host..." >&2
stty -F /dev/hvc0 raw -echo # prevent nl -> cr/nl conversion
echo
@@ -49,10 +55,10 @@ let kernel = config.boot.kernelPackages.kernel; in
serviceConfig.KillSignal = "SIGHUP";
};
# Prevent agetty from being instantiated on ttyS0, since it
# interferes with the backdoor (writes to ttyS0 will randomly fail
# with EIO). Likewise for hvc0.
- systemd.services."serial-getty@ttyS0".enable = false;
+ systemd.services."serial-getty@${serialDevice}".enable = false;
systemd.services."serial-getty@hvc0".enable = false;
boot.initrd.preDeviceCommands =
@@ -88,7 +94,7 @@ let kernel = config.boot.kernelPackages.kernel; in
# Panic if an error occurs in stage 1 (rather than waiting for
# user intervention).
boot.kernelParams =
- [ "console=ttyS0" "panic=1" "boot.panic_on_fail" ];
+ [ "console=${serialDevice}" "panic=1" "boot.panic_on_fail" ];
# `xwininfo' is used by the test driver to query open windows.
environment.systemPackages = [ pkgs.xorg.xwininfo ];
@@ -49,10 +55,10 @@ let kernel = config.boot.kernelPackages.kernel; in
serviceConfig.KillSignal = "SIGHUP";
};
- # Prevent agetty from being instantiated on ttyS0, since it
- # interferes with the backdoor (writes to ttyS0 will randomly fail
+ # Prevent agetty from being instantiated on ${serialDevice}, since it
+ # interferes with the backdoor (writes to ${serialDevice} will randomly fail
# with EIO). Likewise for hvc0.